@@ -62,23 +62,16 @@ $prgname =~ s|^.*/([^/]+)$|\1|;
 $default_includepath = ".:..:@includedir@";
 $tmpdir = "/tmp";
 
-#   Use this function to convert a time() output to a "SUN (13.03.94)"
-#   representation.
 #
-#   Usage: $str = &givetime(time());
+#   A ctime(3) like function.
+#   Usage: $str = &ctime();
 #
-@dow = ( 'Sun', 'Mon', 'Tue', 'Wed', 'Thu', 'Fri', 'Sat' );
-@moy = ( 'Jan', 'Feb', 'Mar', 'Apr', 'May', 'Jun',
-         'Jul', 'Aug', 'Sep', 'Oct', 'Nov', 'Dec' );
-
 sub ctime {
-    my ($str);
+    my ($str, $time);
 
-    local($sec, $min, $hour, $mday, $mon, $year, $wday, $yday, $isdst) =
-        localtime(time());
-    $str = sprintf("%s %s %2d %02d:%02d:%02d 19%s%s", 
-        $dow[$wday], $moy[$mon], $mday, $hour, $min, $sec, $year, 
-        $isdst ? " DST" : "");
+    $time = time();
+    $str  = scalar(localtime($time));
+    $str .= ([localtime($time)]->[8]) ? " DST" : "";
     return $str;
 }
 
