@@ -43,7 +43,7 @@ require 5.0;
 require "smake_misc.pl";
 require "smake_getopts.pl";
 require "smake_file.pl";
-require "smake_vers.pl";
+require "smake_version.pl";
 
 #
 #   print command line usage
@@ -73,14 +73,14 @@ if ($opt_h) {
     exit $EX{'OK'};
 }
 if ($opt_V) {
-    print "$SMake_Hello\n";
+    print "$smake_Hello\n";
     exit $EX{'OK'};
 }
 if ($#ARGV == -1) {
     $makedir = '.';
 }
 elsif ($#ARGV == 0) {
-    $makedir = &file'CanonFilename($ARGV[0]);
+    $makedir = &file::CanonFilename($ARGV[0]);
 }
 else {
     &usage;
@@ -112,13 +112,13 @@ if ($smakepath eq '') {
     print "$prgname: program \`\`smake\'\' not found\n";
     exit $EX{'OSERR'};
 }
-$smakepath = &file'CanonFilename($smakepath);
+$smakepath = &file::CanonFilename($smakepath);
 if ($makedir =~ m|^/.*|) {
-    $smakepath = &file'AbsFilename($smakepath);
+    $smakepath = &file::AbsFilename($smakepath);
 }
 else {
     if ($smakepath !~ m|^/.*|) {
-        $smakepath = &file'CanonFilename(&file'RevPath($makedir) . '/' . $smakepath);
+        $smakepath = &file::CanonFilename(&file::RevPath($makedir) . '/' . $smakepath);
 	}
 }
 
@@ -133,7 +133,7 @@ foreach $path (@includepath) {
         push(@includepathnew, $path);
     }
     else {
-        push(@includepathnew, &file'CanonFilename(&file'RevPath($makedir) . '/' . $path));
+        push(@includepathnew, &file::CanonFilename(&file::RevPath($makedir) . '/' . $path));
     }
 }
 $includepath = join(':', @includepathnew);
@@ -141,7 +141,7 @@ $includepath = join(':', @includepathnew);
 #$definclpath = $smakepath;
 #$definclpath =~ s|^(.*)/[^/]+$|\1|;
 #$definclpath = $definclpath . "/include";
-#$definclpath = &file'CanonFilename($definclpath);
+#$definclpath = &file::CanonFilename($definclpath);
 #$includepath = $includepath . ':' . $definclpath;
 
 
@@ -157,7 +157,7 @@ sub ProcessDir {
         $echodir = "$echodir/";
     }
 
-    @flist = sort(&file'xfts($dir));
+    @flist = sort(&file::xfts($dir));
     @flistfile = ();
     @flistdir = ();
     foreach $filepath (@flist) {
@@ -171,7 +171,7 @@ sub ProcessDir {
     @flist = (sort(@flistfile), sort(@flistdir));
 
     foreach $filepath (@flist) {
-        $filepath = &file'CanonFilename($filepath);
+        $filepath = &file::CanonFilename($filepath);
         $filename = $filepath;
         $filename =~ s|^.*/([^/]+)$|\1|;
 
@@ -193,7 +193,7 @@ sub ProcessDir {
                     push(@inclpathnew, $path);
                 }
                 else {
-                    push(@inclpathnew, &file'CanonFilename("../$path"));
+                    push(@inclpathnew, &file::CanonFilename("../$path"));
                 }
             }
             $inclpathCur = "@inclpathnew";
@@ -206,7 +206,7 @@ sub ProcessDir {
             else {
                 $smakepathCur = "../$smakepath";
             }
-            $smakepathCur = &file'CanonFilename($smakepathCur);
+            $smakepathCur = &file::CanonFilename($smakepathCur);
 
             #   process subdir
             if ($quiet == 0) {
